@@ -11,6 +11,7 @@ class Employee(QuickbooksManagedObject, QuickbooksTransactionEntity):
     class_dict = {
         "PrimaryAddr": Address,
         "PrimaryPhone": PhoneNumber,
+        "Mobile": PhoneNumber,
         "PrimaryEmailAddr": EmailAddress
     }
 
@@ -37,6 +38,9 @@ class Employee(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.Organization = False
         self.BillableTime = False
 
+        self.PrimaryPhone = None
+        self.Mobile = None
+
         self.PrimaryAddr = None
         self.PrimaryEmailAddr = None
 
